@@ -1,7 +1,8 @@
 import sys
 import glob
 from assembler import (assemble, ascii_binary_to_real_binary,
-                       ascii_binary_to_vhdl_code, ascii_binary_to_c_code)
+                       ascii_binary_to_vhdl_code, ascii_binary_to_c_code,
+                       ascii_binary_to_fakemem_code)
 
 
 def main():
@@ -44,6 +45,7 @@ def main():
         ascii_mode = '--ascii' in sys.argv
         vhdl_mode = '--vhdl' in sys.argv
         c_mode = '--c' in sys.argv
+        fakemem_mode = '--fakemem' in sys.argv
 
         if vhdl_mode:
             ascii_binary_to_vhdl_code(ascii_binary)
@@ -51,6 +53,9 @@ def main():
         if c_mode:
             ascii_binary_to_c_code(ascii_binary)
 
+        if fakemem_mode:
+            ascii_binary_to_fakemem_code(ascii_binary)
+
         with open(path + '.out', 'w') as f:
             f.write(
                 ascii_binary
