@@ -186,6 +186,7 @@ def ascii_binary_to_vhdl_code(ascii_binary):
     print "    " + str(i + 1) + "  => \"0000000000000000\""
     print ");"
 
+
 def ascii_binary_to_c_code(ascii_binary):
     number_of_instructions = len(ascii_binary)/32
     low = []
@@ -209,3 +210,28 @@ def ascii_binary_to_c_code(ascii_binary):
         print "set_cpu_memory(&cpu_bus, %s, %s);" % (hex(i), high[i])
 
     print "fpga_set_state(&cpu_bus, RUN);"
+
+
+def ascii_binary_to_fakemem_code(ascii_binary):
+    number_of_instructions = len(ascii_binary)/32
+    low = []
+    high = []
+
+    for _ in xrange(number_of_instructions):
+        high_n = ascii_binary[:16]
+        low_n = ascii_binary[16:32]
+        ascii_binary = ascii_binary[32:]
+        low.append(hex(int(low_n, 2)))
+        high.append(hex(int(high_n, 2)))
+
+    print "-- HIGH"
+    entire_high = [high[i][2:] for i in range(number_of_instructions)]
+    split_high = [entire_high[i:i+64] for i in range(0, len(entire_high), 64)]
+    print ",\n".join(["INIT_" + str(i).zfill(2) + " => \"" + ("".join(line)
+                      + "\"").zfill(64) for i, line in enumerate(split_high)])
+
+    print "-- LOW"
+    entire_low = [low[i][2:] for i in range(number_of_instructions)]
+    split_low = [entire_low[i:i+64] for i in range(0, len(entire_low), 64)]
+    print ",\n".join(["INIT_" + str(i).zfill(2) + " => \"" + ("".join(line)
+                      + "\"").zfill(64) for i, line in enumerate(split_low)])
